@@ -1,13 +1,14 @@
 
-import torch
+
 from rwkvstic.agnostic.backends import Backends
 from rwkvstic.agnostic.backends.base import module
-import torch
+
 from typing import Dict
 from tqdm import tqdm
 
 
 def loadWeights(mode, Path, *args, **kwargs):
+    import torch
     n_layer = 0
 
     w: Dict[str, torch.Tensor] = torch.load(
@@ -44,7 +45,7 @@ def loadWeights(mode, Path, *args, **kwargs):
     # Transform Weights from backend
     for x in tqdm(list(w.keys())):
         if "emb.weight" in x:
-            w[x] = ops.stack(list(map(lambda rrx: ops.initTensor(
+            w[x] = ops.stack(list(map(lambda rrx: ops.initCpuTensor(
                 rrx.squeeze()), w[x].split(1, 0))))
         else:
             w[x] = ops.initTensor(w[x])
